@@ -147,7 +147,7 @@ class EventsRuleToLambda(
             lambda_function_props=lambda_function_props,
         )
 
-        jsii.create(EventsRuleToLambda, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRule")
